orderize_string

Function orderize_string 

pub fn orderize_string(input: &str) -> String
Normalizes the string use Unicode = NFKC normalization, and then removes any characters that are not alphanumeric, whitespace, or ASCII punctuation. This is a “rough” collation that is used to orderize strings for encryption.

Eventually, this will move to a more sophisticated collation that can handle more complex strings using the Unicode Collation Algorithm.